@@ -47,11 +47,12 @@ try:
     from .chainApproximation_c import compress
     from .fabba_agg_memview import aggregate as aggregate_fabba 
     # cython with memory view
-    from .caggregation_memview import aggregate as aggregate_fc 
+    from .aggregation_memview import aggregate as aggregate_fc 
     # cython with memory view
 except ModuleNotFoundError:
     warnings.warn("cython fail.")
     from .chainApproximation import compress
+    from .fabba_agg import aggregate as aggregate_fabba 
     from .aggregation import aggregate as aggregate_fc
 
     
@@ -541,15 +542,9 @@ class fabba_model(Aggregation2D):
         
         if self.sorting in ["lexi", "2-norm", "1-norm"]:
             # warnings.warn(f"Pass {self.sorting} as keyword args. From the next version ", FutureWarning)
-            try:
-                labels, splist = aggregate_fabba(npieces, self.sorting, self.alpha)
-            except:
-                labels, splist = self.aggregate(npieces)
+            labels, splist = aggregate_fabba(npieces, self.sorting, self.alpha)
         else:
-            try:
-                labels, splist = aggregate_fc(npieces, self.sorting, self.alpha)
-            except:
-                raise ValueError(f"Cython initialization fails, will be fixed in the future version.")
+            labels, splist = aggregate_fc(npieces, self.sorting, self.alpha)
 
         centers = np.zeros((0,2))
         
